@@ -3,8 +3,9 @@
 
 $title = 'Bisqwit\'s identd';
 $progname = 'bidentd';
+$git = 'git://bisqwit.iki.fi/bidentd.git';
 
-$k='';foreach(file('/home/bisqwit/src/unixtools/ident/ChangeLog') as $s)$k.=$s;
+$k='';foreach(file('/home/bisqwit/src/bidentd/ChangeLog') as $s)$k.=$s;
 
 $text = array(
    '1. Purpose' => "
@@ -16,8 +17,8 @@ The package for your architechture can be downloaded from any official Debian mi
 
 ", '1. Why another identd daemon?' => "
 
-Because there is not one other one which
-worked correctly over multiple NATs.
+Because there is no other (wasn't in 2000 at least)
+which worked correctly over multiple NATs.
 <br>
         The program works like an ident daemon is supposed to work.
         It allows people to query who's connecting in which port.
@@ -48,8 +49,8 @@ Since 1.1.0, kernel family 2.6 is supported too.
 
 ", '1. Copying' => "
 
-bidentd has been written by Joel Yliluoma, a.k.a.
-<a href=\"http://iki.fi/bisqwit/\">Bisqwit</a>,
+bidentd has been written by
+<a href=\"http://iki.fi/bisqwit/\">Joel Yliluoma</a>,
 and is distributed under the terms of the
 <a href=\"http://www.gnu.org/licenses/licenses.html#GPL\">General Public License</a> (GPL).
 
